@@ -32,8 +32,8 @@ class LightgbmAlgorithm(BaseAlgorithm):
         self.model_file = self.uid + ".lgbm.model"
         self.model_file_path = os.path.join(storage_path, self.model_file)
 
-        self.rounds = additional.get("one_step", 50)
-        self.max_iters = additional.get("max_steps", 3)
+        self.rounds = additional.get("trees_in_step", 50)
+        self.max_iters = additional.get("max_steps", 500)
         self.learner_params = {
             "boosting_type": "gbdt",
             "objective": self.params.get("objective", "binary"),
@@ -109,14 +109,7 @@ lgbm_bin_params = {
     "objective": ["binary"],
     "metric": ["binary_logloss", "auc"],
     "num_leaves": [2, 4, 8, 16, 32, 64, 128, 256, 512, 1024],
-    "learning_rate": [
-        0.05,
-        0.1,
-        0.15,
-        0.2,
-        0.25,
-        0.3,
-    ],
+    "learning_rate": [0.05, 0.1, 0.15, 0.2, 0.25, 0.3],
     "feature_fraction": [0.3, 0.4, 0.5, 0.6, 0.7, 0.8, 0.9, 1.0],
     "bagging_fraction": [0.3, 0.4, 0.5, 0.6, 0.7, 0.8, 0.9, 1.0],
     "bagging_freq": [0, 1, 2, 3, 4, 5],
@@ -124,7 +117,7 @@ lgbm_bin_params = {
 
 
 additional = {
-    "one_step": 50,
+    "trees_in_step": 50,
     "train_cant_improve_limit": 5,
     "max_steps": 500,
     "max_rows_limit": None,
