@@ -59,7 +59,12 @@ class AutoML:
         tuning_mode="Sport",
         train_ensemble=True,
         optimize_metric=None,
-        validation={"validation_type": "kfold", "k_folds": 5, "shuffle": True},
+        validation={
+            "validation_type": "kfold",
+            "k_folds": 5,
+            "shuffle": True,
+            "stratify": True,
+        },
         verbose=True,
         ml_task=None,
         seed=1,
@@ -308,50 +313,6 @@ class AutoML:
             ldb["train_time"] += [np.round(m.get_train_time(), 2)]
         return pd.DataFrame(ldb)
 
-    def get_additional_metrics(self):
-
-        additional_metrics = self._best_model.get_additional_metrics()
-        # AdditionalMetrics.compute(
-        #    oof_predictions[target_cols],
-        #    oof_predictions[prediction_cols],
-        #    self._ml_task,
-        # )
-        if self._ml_task == BINARY_CLASSIFICATION:
-
-            self._metrics_details = additional_metrics["metric_details"]
-            self._max_metrics = additional_metrics["max_metrics"]
-            self._confusion_matrix = additional_metrics["confusion_matrix"]
-            self._threshold = additional_metrics["threshold"]
-            logger.info(
-                "Metric details:\n{}\n\nConfusion matrix:\n{}".format(
-                    self._max_metrics.transpose(), self._confusion_matrix
-                )
-            )
-            with open(
-                os.path.join(self._results_path, "best_model_metrics.txt"), "w"
-            ) as fout:
-                fout.write(
-                    "Metric details:\n{}\n\nConfusion matrix:\n{}".format(
-                        self._max_metrics.transpose(), self._confusion_matrix
-                    )
-                )
-
-        elif self._ml_task == MULTICLASS_CLASSIFICATION:
-
-            max_metrics = additional_metrics["max_metrics"]
-            confusion_matrix = additional_metrics["confusion_matrix"]
-
-            logger.info(
-                "Metric details:\n{}\nConfusion matrix:\n{}".format(
-                    max_metrics, confusion_matrix
-                )
-            )
-            with open(
-                os.path.join(self._results_path, "best_model_metrics.txt"), "w"
-            ) as fout:
-                fout.write("Metric details:\n{}\n\n".format(max_metrics.transpose()))
-                fout.write("Confusion matrix:\n{}".format(confusion_matrix))
-
     def keep_model(self, model):
         if model is None:
             return
@@ -420,22 +381,43 @@ class AutoML:
         if self._total_time_limit is None:
             return True
 
-        total_time_already_spend = (
+        total_time_spend = 0.0
+        for k, v in self._models_train_time.items():
+            total_time_spend += np.sum(v)
+
+        # no time left, do not train more models, sorry ...
+        time_left = self._total_time_limit - total_time_spend 
+        if time_left < 0:
+            return False
+
+        # there is still time and model_type was not tested yet
+        # we should try it
+        if (
+            time_left > 0
+            and model_type not in self._models_train_time
+        ):
+            return True
+
+        model_total_time_spend = (
             0
             if model_type not in self._models_train_time
             else np.sum(self._models_train_time[model_type])
         )
-        mean_time_already_spend = (
+        model_mean_time_spend = (
             0
             if model_type not in self._models_train_time
             else np.mean(self._models_train_time[model_type])
         )
 
-        if (
-            total_time_already_spend + mean_time_already_spend
-            < 0.85 * self._total_time_limit / float(len(self._algorithms))
-        ):
+        algo_cnt = float(len(self._algorithms))
+        for a in ["Baseline", "Decision Tree"]:
+            if a in self._algorithms:
+                algo_cnt -= 1.0
+
+        model_time_left = time_left / algo_cnt
+        if model_mean_time_spend <= model_time_left:
             return True
+
         return False
 
     def ensemble_step(self):
@@ -476,6 +458,9 @@ class AutoML:
                     self._ml_task, AlgorithmsRegistry.get_supported_ml_tasks()
                 )
             )
+        if self._ml_task == REGRESSION:
+            if "stratify" in self._validation:
+                del self._validation["stratify"]
         logger.info("AutoML task to be solved: {}".format(self._ml_task))
         print(f"AutoML task to be solved: { self._ml_task}")
 
@@ -682,7 +667,6 @@ class AutoML:
                     self._best_model = m
                     max_loss = m.get_final_loss()
 
-            self.get_additional_metrics()
             self._fit_time = time.time() - start_time
             # self._progress_bar.close()
 
